/* This file contains two datasets on promotions and faction shares
1. promotion_regression_sample.dta contains individual-level promotion dummy and individual characteristics
2. stability.dta contains faction-level shares at each level of Congress

Results: We justify our modeling assumptions.
Here I list a few other variables that are not used in our existing tables, but could be potentially useful

*****************************************
1. promotion_regression_sample.dta 
* share_seat: share of politicians in the same group in the whole congress
* share_score: share of Bo's score of the group that a politician belongs to
* share_H1: share of politicians in the same group one level above a politician i
* share_L1: share of politicians in the same group one level below a politician i
*****************************************
2. stability.dta 
* CYCL_score: share of Bo's score of the CYLC in each year
*/

/* Set to your dropbox path
*/
cd ".\working"
*
******************************************

* Why do not we operate at the aggegrate faction level? 
* Here the unit of analysis is the faction, not party member. There is a power-sharing game going on between the various groups in the background.
* Is this warranted? No.
* Result 1: No strong pattern of reversion in faction strength when the other faction is stronger in the previous period
* Result 2: No way of testing whether Princelings behave like a faction or not based on these regressions. No evidence of differential behavior of Prncelings vs. other factions 
 
 *****************************************
* Code to produce existing tables in the paper (maybe helpful for understanding the variable definition)
*****************************************
use stability, clear 
tsset year, yearly
* focus from last CCP 11th CC
keep  if year>1977
* Time series analysis so we adjust for autocorrelation

local factionlist  CYLC Shanghai Military  Princelings
foreach faction of local factionlist  {
label var `faction'_Score "`faction' score"
}


eststo clear
// CYLC
eststo :  prais  CYLC_Score l.CYLC_Score l.Shanghai_Score, corc
// Shanghai
eststo: prais Shanghai_Score l.Shanghai_Score l.CYLC_Score, corc
// CYLC (adding princelings)
eststo: prais CYLC_Score l.CYLC_Score  l.Shanghai_Score  l.Princelings_Score l.Military_Score, corc
// Shanghai
eststo:  prais Shanghai_Score l.Shanghai_Score l.CYLC_Score l.Princelings_Score l.Military_Score, corc
// Princelings
eststo:  prais Princelings_Score l.Princelings_Score  l.CYLC_Score  l.Shanghai_Score l.Military_Score, corc
// Military
eststo:  prais Military_Score l.Shanghai_Score l.CYLC_Score l.Princelings_Score l.Military_Score, corc

esttab

capture: esttab using "D:\Dropbox\Chinese Politics\paper\table_figure\ecma_time_series.tex", ///
s(  N r2_a, label("Observations" "Adj. R-squared") ///
 fmt(  0 %9.2f ) )  mtitles("CYLC" "Shanghai" "CYLC" "Shanghai" "Princelings" "Military")  ///
width(\hsize) se star(* 0.1 ** 0.05 *** 0.01) ar2  br lab  replace nocon nonotes



*****************************************

* Is there an effect of balancing among factions that is detectable at the level of individual promotions?

use stability, clear
tsset year, yearly
foreach var of varlist CYLC_Score Shanghai_Score Princelings_Score  Military_Score {
	*gen backward 10yr moving average (also tried 5yr)
	gen m`var' = (L1.`var' + L2.`var' + L3.`var' + L4.`var' + L5.`var'+ L6.`var' + L7.`var' + L8.`var' + L9.`var' + L10.`var') / 10
	*gen m`var' = (L1.`var' + L2.`var' + L3.`var' + L4.`var' + L5.`var') / 5
	*gen a variable increasing in underrepresentation relative to the moving average
	gen under_`var' = m`var' - `var'
}
keep year under_*
sort year
save "underrepresented_factions.dta", replace

use stability, clear
tsset year, yearly
foreach var of varlist CYLC_Score Shanghai_Score Princelings_Score  Military_Score {
	*gen backward 10yr moving average (also tried 5yr)
	gen m`var' = (L1.`var' + L2.`var' + L3.`var' + L4.`var' + L5.`var') / 5
	*gen a variable increasing in underrepresentation relative to the moving average
	gen under_`var'_5year = m`var' - `var'
}
keep year under_*_5year
sort year
save "underrepresented_factions_5year.dta", replace

* Conditional faction premia (Table 3) with factional imbalance
use promotion_regression_sample, clear
keep if ladder>1 & CC_no>=11 & CC_no<=17
g cons=1

sort year
merge m:1 year using "underrepresented_factions"
keep if _m==3
drop _m
merge m:1 year using "underrepresented_factions_5year"
keep if _m==3
drop _m



local factionlist  CYLC Shanghai Military  Princelings
foreach faction of local factionlist  {
g `faction'_imb = `faction'*under_`faction'_Score
label var `faction'_imb "`faction'*`faction' imbalance"
g `faction'_imb_5year = `faction'*under_`faction'_Score_5year
label var `faction'_imb_5year "`faction'*`faction' imbalance"
}



eststo clear
local y dum_promotion
*local z   share_seat
local x CYLC CYLC_CYLC_sec CYLC_CYLC_SC CYLC_imb Shanghai Shanghai_Shanghai_sec Shanghai_Shanghai_SC Shanghai_imb ///
Princelings Princelings_Princelings_SC Princelings_Princelings_sec Princelings_imb ///
 Military Military_Military_SC Military_Military_sec Military_imb
local contr  gender college_dum gschool_dum mishu_dum ethnic_dum abroad_dum agez agez2 agez3    
local c ladder>1 & CC_no>=11
* no fe
eststo All1: reghdfe `y' `z'  `x'  `contr'  if  `c' , ab(cons) vce(rob) 
estadd local indi "Yes"
estadd local FE1 "No"
estadd local FE "No"
estadd local sample "All"
* ladder fe
eststo All2: reghdfe `y' `z' `x'  `contr'  if  `c' , ab(ladder) vce(rob) 
estadd local indi "Yes"
estadd local FE1 "Yes"
estadd local FE "No"
estadd local sample "All"
* ladder year fe
eststo All3: reghdfe `y' `z' `x'  `contr'  if `c', ab(ladder  year) vce(rob) 
estadd local indi "Yes"
estadd local FE1 "Yes"
estadd local FE "Yes"
estadd local sample "All"
esttab
capture: esttab using "D:\Dropbox\Chinese Politics\paper\table_figure\ecma_panel.tex", ///
keep( CYLC_CYLC_sec CYLC_CYLC_SC  CYLC_imb  /// 
Shanghai_Shanghai_sec Shanghai_Shanghai_SC Shanghai_imb ///
  Princelings_Princelings_sec Princelings_Princelings_SC Princelings_imb ///
  Military_Military_sec Military_Military_SC Military_imb ) ///
  order( CYLC_CYLC_sec CYLC_CYLC_SC  CYLC_imb  /// 
Shanghai_Shanghai_sec Shanghai_Shanghai_SC Shanghai_imb ///
  Princelings_Princelings_sec Princelings_Princelings_SC Princelings_imb ///
  Military_Military_sec Military_Military_SC Military_imb ) ///
s(sample indi FE1 FE  N r2_a, label("Sample"  "Individual Attributes"  "Level F.E." "Year F.E." "Observations" "Adj. R-squared") ///
 fmt( 0 0 0 0  0 %9.2f ) )  mtitles("Promotion" "Promotion" "Promotion")  ///
width(\hsize) se star(* 0.1 ** 0.05 *** 0.01) ar2  br lab  replace nocon nonotes






eststo clear
local y dum_promotion
*local z   share_seat
local x CYLC CYLC_CYLC_sec CYLC_CYLC_SC CYLC_imb_5year Shanghai Shanghai_Shanghai_sec Shanghai_Shanghai_SC Shanghai_imb_5year ///
Princelings Princelings_Princelings_SC Princelings_Princelings_sec Princelings_imb_5year ///
 Military Military_Military_SC Military_Military_sec Military_imb_5year
local contr  gender college_dum gschool_dum mishu_dum ethnic_dum abroad_dum agez agez2 agez3    
local c ladder>1 & CC_no>=11
* no fe
eststo All1: reghdfe `y' `z'  `x'  `contr'  if  `c' , ab(cons) vce(rob) 
estadd local indi "Yes"
estadd local FE1 "No"
estadd local FE "No"
estadd local sample "All"
* ladder fe
eststo All2: reghdfe `y' `z' `x'  `contr'  if  `c' , ab(ladder) vce(rob) 
estadd local indi "Yes"
estadd local FE1 "Yes"
estadd local FE "No"
estadd local sample "All"
* ladder year fe
eststo All3: reghdfe `y' `z' `x'  `contr'  if `c', ab(ladder  year) vce(rob) 
estadd local indi "Yes"
estadd local FE1 "Yes"
estadd local FE "Yes"
estadd local sample "All"
esttab
capture: esttab using "D:\Dropbox\Chinese Politics\paper\table_figure\ecma_panel_5year.tex", ///
keep( CYLC_CYLC_sec CYLC_CYLC_SC  CYLC_imb_5year  /// 
Shanghai_Shanghai_sec Shanghai_Shanghai_SC Shanghai_imb_5year ///
  Princelings_Princelings_sec Princelings_Princelings_SC Princelings_imb_5year ///
  Military_Military_sec Military_Military_SC Military_imb_5year ) ///
  order( CYLC_CYLC_sec CYLC_CYLC_SC  CYLC_imb_5year  /// 
Shanghai_Shanghai_sec Shanghai_Shanghai_SC Shanghai_imb_5year ///
  Princelings_Princelings_sec Princelings_Princelings_SC Princelings_imb_5year ///
  Military_Military_sec Military_Military_SC Military_imb_5year ) ///
s(sample indi FE1 FE  N r2_a, label("Sample"  "Individual Attributes"  "Level F.E." "Year F.E." "Observations" "Adj. R-squared") ///
 fmt( 0 0 0 0  0 %9.2f ) )  mtitles("Promotion" "Promotion" "Promotion")  ///
width(\hsize) se star(* 0.1 ** 0.05 *** 0.01) ar2  br lab  replace nocon nonotes

